@@ -1,9 +1,9 @@
 //
 //  OSSP asgui - Accounting system graphical user interface
-//  Copyright (c) 2002-2003 The OSSP Project (http://www.ossp.org/)
-//  Copyright (c) 2002-2003 Ralf S. Engelschall <rse@engelschall.com>
-//  Copyright (c) 2002-2003 Michael Schloh von Bennewitz <michael@schloh.com>
-//  Copyright (c) 2002-2003 Cable & Wireless Telecommunications Services GmbH
+//  Copyright (c) 2002-2004 The OSSP Project (http://www.ossp.org/)
+//  Copyright (c) 2002-2004 Ralf S. Engelschall <rse@engelschall.com>
+//  Copyright (c) 2002-2004 Michael Schloh von Bennewitz <michael@schloh.com>
+//  Copyright (c) 2002-2004 Cable & Wireless Telecommunications Services GmbH
 //
 //  This file is part of OSSP asgui, an accounting system graphical user
 //  interface which can be found at http://www.ossp.org/pkg/tool/asgui/.
@@ -26,7 +26,7 @@
 //  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 //  SUCH DAMAGE.
 //
-//  titraq.h: ISO C++ interface
+//  as_gui.h: ISO C++ interface
 //
 
 #ifndef AS_GUI_MWIN_H
@@ -92,44 +92,23 @@ typedef unsigned long        U32;
 ?==Error: Undefined 32 bit type
 #endif // U32
 
-#if (SIZEOF_SHORT == 8)
-typedef unsigned short       U64;
-#elif (SIZEOF_INT == 8)
-typedef unsigned int         U64;
-#elif (SIZEOF_LONG == 8)
-typedef unsigned long        U64;
-#elif (SIZEOF_LONG_LONG == 8)
-typedef unsigned long long   U64;
-#else
-?==Error: Undefined 64 bit type
-#endif // U64
-
 #else // HAVE_CONFIG_H (not defined)
 typedef unsigned char        U8;
-#if (4 == 8)
-typedef unsigned int         U64;
-#elif (4 == 8)
-typedef unsigned long        U64;
-#elif (8 == 8)
-typedef unsigned long long   U64;
-#else
-?==Error: Undefined 64 bit type
-#endif
 
-#if (4 == 2)
-typedef	unsigned int         U16;
-#elif (2 == 2)
+#if (2 == 2)
 typedef	unsigned short       U16;
+#elif (4 == 2)
+typedef	unsigned int         U16;
 #else
 ?==Error: Undefined 16 bit type
 #endif
 
-#if (4 == 4)
+#if (2 == 4)
+typedef	unsigned short       U32;
+#elif (4 == 4)
 typedef	unsigned int         U32;
 #elif (4 == 4)
 typedef	unsigned long        U32;
-#elif (2 == 4)
-typedef	unsigned short       U32;
 #else
 ?== Error: Undefined 32 bit type
 #endif
