@@ -1,9 +1,9 @@
 //
 //  OSSP asgui - Accounting system graphical user interface
-//  Copyright (c) 2002-2003 The OSSP Project (http://www.ossp.org/)
-//  Copyright (c) 2002-2003 Ralf S. Engelschall <rse@engelschall.com>
-//  Copyright (c) 2002-2003 Michael Schloh von Bennewitz <michael@schloh.com>
-//  Copyright (c) 2002-2003 Cable & Wireless Telecommunications Services GmbH
+//  Copyright (c) 2002-2004 The OSSP Project (http://www.ossp.org/)
+//  Copyright (c) 2002-2004 Ralf S. Engelschall <rse@engelschall.com>
+//  Copyright (c) 2002-2004 Michael Schloh von Bennewitz <michael@schloh.com>
+//  Copyright (c) 2002-2004 Cable & Wireless Telecommunications Services GmbH
 //
 //  This file is part of OSSP asgui, an accounting system graphical user
 //  interface which can be found at http://www.ossp.org/pkg/tool/asgui/.
@@ -26,7 +26,7 @@
 //  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 //  SUCH DAMAGE.
 //
-//  titslot.cpp: ISO C++ implementation
+//  as_slot.cpp: ISO C++ implementation
 //
 
 // system headers
@@ -168,6 +168,12 @@ void Titraqform::addEntry(int nRows)
         m_pMaintable->setDirty();   // Set data to dirty state
         m_pMaintable->setCurrentCell(Select.topRow(), m_pMaintable->currentColumn());
 
+        // According to Trolltech, insertRows() ''clears the selection(s).
+        // They are pretty wrong about that, so unfortunately we'll have to
+        // take care of the dirty work ourselves with a clearSelection().
+        m_pMaintable->clearSelection(false);
+        m_pMaintable->selectRow(m_pMaintable->currentRow());
+
         // Update relevant data fields for all new rows
         for (int nIter = 0; nIter < nTotal; nIter++) {
             m_pMaintable->setText(Select.topRow() + nIter, TITRAQ_IDXSTATUS, QString(QChar('W')));
@@ -192,6 +198,12 @@ void Titraqform::addEntry(int nRows)
         m_pMaintable->setDirty();   // Set data to dirty state
         m_pMaintable->setCurrentCell(Select.bottomRow() + 1, m_pMaintable->currentColumn());
 
+        // According to Trolltech, insertRows() ''clears the selection(s).
+        // They are pretty wrong about that, so unfortunately we'll have to
+        // take care of the dirty work ourselves with a clearSelection().
+        m_pMaintable->clearSelection(false);
+        m_pMaintable->selectRow(m_pMaintable->currentRow());
+
         // Update relevant data fields for all new rows
         for (int nIter = 1; nIter <= nTotal; nIter++) {
             m_pMaintable->setText(Select.bottomRow() + nIter, TITRAQ_IDXSTATUS, QString(QChar('W')));
